/*
 * ElementList.java
 *
 * Created on February 18, 2002, 8:26 AM
 */

import java.util.Vector;
import java.util.Enumeration;

/**
 * This class is used to maintain a list of XMLElement objects.
 * It is implemented using a java.util.Vector object.
 *
 * @author  andrewm
 * @version 
 */
public class ElementList 
{
	// Vector which holds the elements
	Vector xmlElements;
	
	/** Creates new ElementList */
    public ElementList() 
	{
		xmlElements = new Vector();
    }

	/**
	 * This method creates and adds a new XMLElement to the Vector of elements
	 * 
	 * @param pathID Path id of the element
	 * @param name Name of the element
	 * @param startIndex Starting index of the element
	 * @param previousElementID id of the previous element
	 * @return int element id of the element that was just added
	 */
	public int addElement( int pathID, String name, int startIndex, int previousElementID )
	{
		// Create a new XMLElement object
		XMLElement element = new XMLElement( pathID, name, startIndex, previousElementID );
		
		// Add the element to the elements vector
		xmlElements.add( element );
		
		// Return the size of the Vector which is the position of the element
		// in the vector + 1 to keep the element id 1 based.
		return xmlElements.size();
	}
	
	/**
	 * Retrieves the element with the element id that is passed in.
	 * 
	 * @param elementID ID of the element that is requested
	 * @return XMLElement XMLElement being retrieved
	 */
	public XMLElement getElement( int elementID )
	{
		return (XMLElement)xmlElements.get( elementID - 1 );
	}
	
	/**
	 * Returns the list of elements as an enumeration
	 * 
	 * @return Enumeration Enumeration of the element list
	 */
	public Enumeration getElements()
	{
		return xmlElements.elements();
	}	
	
	/**
	 * Sets an element into the element list at the specified location
	 *
	 * @param element Element to be placed into the element list
	 * @param elementID ID of the element being placed into the element list
	 */
	public void setElement( Object element, int elementID )
	{
		xmlElements.set( elementID - 1, element );
	}
}
